<?php
/**
 * @copyright	Copyright (c) 2013 Skyline Software (http://extstore.com). All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die();

jimport('joomla.plugin.plugin');
// require JomSocial core library
require_once(JPATH_ROOT . '/components/com_community/libraries/core.php');

/**
 * Community - Profile Navigation Plugin
 *
 * @package		Joomla.Plugin
 * @subpakage	Skyline.ProfileNavigation
 */
class plgCommunitySL_ProfileNavigation extends JPlugin {
	/** @var string */
	var $name			= 'SL_ProfileNavigation';
	/** @var string */
	var $_name			= 'sl_profilenavigation';
	/** @var user object */
	var $_user			= null;
	/** @var user object */
	var $_my			= null;

	/**
	 * Constructor
	 *
	 * @param string $subject
	 * @param mixed $config
	 */
	function __construct(&$subject, $config) {
		$this->_user		= CFactory::getRequestUser();
		$this->_my			= CFactory::getUser();

		parent::__construct($subject, $config);
	}

	/**
	 * On user profile display
	 */
	function onProfileDisplay() {
		// get javascript type
		$javascript = $this->params->get('javascript', 1);

		// add header
		$document	= &JFactory::getDocument();
		$live_site	= JURI::base(true);

		$document->addStyleSheet($live_site . '/plugins/community/sl_profilenavigation/assets/css/style.css');
		$ie = <<<DOCHERE
<!--[if lte IE 8]>
	<link rel="stylesheet" href="$live_site/plugins/community/sl_profilenavigation/assets/css/ie7.css" />
<![endif]-->
DOCHERE;

		$document->addCustomTag($ie);

		$document->addScript($live_site . '/plugins/community/sl_profilenavigation/assets/js/script.js');
		/*
		if ($javascript == 1) {
			JHTML::_('behavior.mootools');
			$document->addScript("$live_site/plugins/community/sl_profilenavigation/mootoolsfx.js");
			$transition = $this->params->get('transition', 'Fx.Transitions.linear');
			$duration = $this->params->get('duration', 300);
			$fps = $this->params->get('fps', 50);
			$document->addScriptDeclaration($script);
		}
		*/

		// get next/previous profile
		$prevUser = $this->_getNavUser(false);
		$nextUser = $this->_getNavUser();

		// display app
		$ret = '';

		if ($prevUser) {
			$this->_processUserInfo($prevUser);
			$prevProfile = $prevUser->username;
			$ret .= <<<DOCHERE
<div id="sl_jspn_prev" class="sl_jspn_prev">
	<a href="$prevUser->link" title="$prevProfile">
		<div class="sl_jspn_outer">
			<div class="sl_jspn_inner">
				<div class="sl_jspn_username">
					$prevUser->username
				</div>
				<div class="sl_jspn_avatar">
					$prevUser->avatar
				</div>
			</div>
		</div>
	</a>
</div>
DOCHERE;
		}

		if ($nextUser) {
			$this->_processUserInfo($nextUser);
			$nextProfile = $nextUser->username;
			$ret .= <<<DOCHERE
<div id="sl_jspn_next" class="sl_jspn_next">
	<a href="$nextUser->link" title="$nextProfile">
		<div class="sl_jspn_outer">
			<div class="sl_jspn_inner">
				<div class="sl_jspn_username">
					$nextUser->username
				</div>
				<div class="sl_jspn_avatar">
					$nextUser->avatar
				</div>
			</div>
		</div>
	</a>
</div>
DOCHERE;
		}

		return $ret;
	}


	/**
	 * Get next/previous profile
	 *
	 * @param boolean $next
	 * @return user object
	 */
	function _getNavUser($next = true) {
		$db = &JFactory::getDBO();

		$query = 'SELECT u.id, u.username, u.name, c.avatar, c.thumb'
			. ' FROM #__users AS u'
			. ' LEFT JOIN #__community_users AS c ON u.id = c.userid'
			. ' WHERE u.id ' . ($next ? '>' : '<') . ' ' . (int) $this->_user->id
			. ' AND u.block = 0'
			. ' ORDER BY u.id ' . ($next ? 'ASC' : 'DESC')
		;
		$db->setQuery($query);

		return $db->loadObject();
	}


	/**
	 * Process user info
	 *
	 * @param user object $user
	 */
	function _processUserInfo(&$user) {
		$Itemid	= JRequest::getInt('Itemid');

		// user link
		$user->link = JRoute::_("index.php?option=com_community&view=profile&userid=$user->id&Itemid=$Itemid");
		// user name
		if ($this->params->get('name_display', 'username') != 'username') {
			$user->username = $user->name;
		}

		// avatar
		$live_site = JURI::base(true);

		if (!$user->thumb || !file_exists(JPATH_ROOT.DS.$user->thumb)) {
			$user->thumb = 'components/com_community/assets/user_thumb.png';
		}

		$user->avatar = "<img src=\"$live_site/$user->thumb\" alt=\"avatar\" />";

		return $user;
	}
}